@@ -1,5 +1,9 @@
 """Introspection for the ``logging`` logger tree in the Standard Library.
 
+You can install this package with the standard ``pip`` command::
+
+    $ pip install logging_tree
+
 While you can write programs that call this package's ``tree()``
 function and examine the hierarchy of logger objects that it finds
 inside of the Standard Library ``logging`` module, the simplest use of
@@ -77,6 +81,15 @@ On older versions of Python you will instead have to install
 Changelog
 ---------
 
+**Version 1.5** - 2014 December 24
+    Handlers now display their logging level if one has been set, and
+    their custom logging formatter if one has been installed.
+
+**Version 1.4** - 2014 January 8
+    Thanks to a contribution from Dave Brondsema, disabled loggers are
+    now actually marked as "Disabled" to make it less of a surprise that
+    they fail to log anything.
+
 **Version 1.3** - 2013 October 29
     Be explicit and display the logger level ``NOTSET`` along with the
     effective level inherited from the logger's ancestors; and display
@@ -100,7 +113,7 @@ Changelog
     Initial release.
 
 """
-__version__ = '1.3'
+__version__ = '1.5'
 __all__ = ('tree', 'printout')
 
 from logging_tree.nodes import tree
